@@ -267,6 +267,7 @@ class AccountMenu(Gtk.Box):
             back_row.emit('activate')
         self._accounts_listbox.remove(row)
         sub_menu = self._stack.get_child_by_name(f'{row.account}-menu')
+        assert sub_menu is not None
         self._stack.remove(sub_menu)
         row.destroy()
         sub_menu.destroy()
@@ -425,13 +426,13 @@ class PageMenuItem(MenuItem):
         super().__init__(name)
 
         if name == 'general':
-            icon = 'preferences-system-symbolic'
+            icon = 'avatar-default-symbolic'
         elif name == 'privacy':
             icon = 'preferences-system-privacy-symbolic'
         elif name == 'connection':
             icon = 'preferences-system-network-symbolic'
         elif name == 'advanced':
-            icon = 'preferences-other-symbolic'
+            icon = 'preferences-system-symbolic'
         else:
             icon = 'dialog-error-symbolic'
 
