@@ -49,9 +49,11 @@ from gajim.common.preview import Preview
 from gajim.common.structs import URI
 from gajim.common.util.text import escape_iri_path_segment
 
+from gajim.gtk.const import MuteState
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import AddChatActionParams
 from gajim.gtk.structs import ChatListEntryParam
+from gajim.gtk.structs import MuteContactParam
 from gajim.gtk.structs import RemoveHistoryActionParams
 from gajim.gtk.structs import RetractMessageParam
 from gajim.gtk.util import GajimMenu
@@ -532,6 +534,21 @@ def get_chat_list_row_menu(workspace_id: str,
         params = AccountJidParam(account=account, jid=jid)
         menu.add_item(_('Mark as read'), 'win.mark-as-read', params)
 
+    if contact.is_muted:
+        menu.add_item(
+            _('Unmute Chat'),
+            'app.mute-chat',
+            MuteContactParam(account=account,
+                             jid=jid,
+                             state=MuteState.UNMUTE))
+    else:
+        submenu = menu.add_submenu(_('Mute Chat'))
+        for state, label in MuteState.iter():
+            submenu.add_item(
+                label,
+                'app.mute-chat',
+                MuteContactParam(account=account, jid=jid, state=state))
+
     return menu
 
 
@@ -778,23 +795,17 @@ def get_format_menu() -> GajimMenu:
     return GajimMenu.from_list(menuitems)
 
 
-def get_workspace_menu(workspace_id: str, has_unread: bool) -> GajimMenu:
+def get_workspace_menu(workspace_id: str) -> GajimMenu:
     remove_action = 'win.dummy'
     if app.settings.get_workspace_count() > 1:
         remove_action = 'win.remove-workspace'
 
     menuitems: MenuItemListT = [
+        (_('Mark as read'), 'win.mark-workspace-as-read', workspace_id),
         (_('Edit…'), 'win.edit-workspace', workspace_id),
         (_('Remove'), remove_action, workspace_id),
     ]
 
-    if has_unread:
-        menuitems.insert(
-            0,
-            (_('Mark as read'),
-             'win.mark-workspace-as-read',
-             workspace_id))
-
     return GajimMenu.from_list(menuitems)
 
 
