@@ -61,6 +61,13 @@ class ChatListEntryParam(VariantMixin):
     jid: JID
 
 
+@dataclass
+class MuteContactParam(VariantMixin):
+    account: str
+    jid: JID
+    state: int
+
+
 @dataclass
 class AccountJidParam(VariantMixin):
     account: str
